@@ -5,7 +5,7 @@ import ext
 import rest
 import utils
 
-from .client import Client, JsonClient
+from .client import Client, JSONClient
 from .factory import create_app
 from .core import (
 	jsonify,
@@ -17,5 +17,5 @@ from .core import (
 	auth
 )
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __author__ = 'Derrick Gilland <dgilland@gmail.com>'
